@@ -3,7 +3,7 @@ import pika
 import pika.exceptions
 import time
 
-class consumer_class(): 
+class ManageConsumers(): 
     def __init__(self, service_name, handler, config):
         self.rabbit_user = config['RABBIT_USER']
         self.rabbit_password = config['RABBIT_PASSWORD']
